/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformwindow.sip"
#include <abstractformwindow.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformwindow.sip"
#include <abstractformwindow.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformwindowcursor.sip"
#include <abstractformwindowcursor.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformeditor.sip"
#include <abstractformeditor.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qdir.sip"
#include <qdir.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 114 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 120 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 126 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 129 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 132 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 135 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 138 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 141 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 144 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 570 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 147 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 619 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 150 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 592 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 153 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 608 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 156 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 675 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 159 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 162 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 165 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 168 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 425 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 171 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 412 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 174 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 398 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 177 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 180 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 183 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 186 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 205 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 189 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 192 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 198 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 201 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 204 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 207 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 210 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 213 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 216 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 219 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 222 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 227 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 230 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 233 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 236 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 239 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 242 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 245 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 248 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 251 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 254 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 257 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerFormWindowInterface.cpp"


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_fileName, "fileName(self) -> str");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_fileName(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_fileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_fileName);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->fileName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_fileName, doc_QDesignerFormWindowInterface_fileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_absoluteDir, "absoluteDir(self) -> QDir");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_absoluteDir(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_absoluteDir(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QDir*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_absoluteDir);
                return SIP_NULLPTR;
            }

            sipRes = new ::QDir(sipCpp->absoluteDir());

            return sipConvertFromNewType(sipRes, sipType_QDir, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_absoluteDir, doc_QDesignerFormWindowInterface_absoluteDir);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_contents, "contents(self) -> str");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_contents(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_contents(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_contents);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->contents());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_contents, doc_QDesignerFormWindowInterface_contents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setContents, "setContents(self, dev: Optional[QIODevice], errorMessage: Optional[Optional[str]] = '') -> bool\n"
"setContents(self, contents: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setContents(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setContents(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QIODevice* a0;
        ::QString* a1 = 0;
        int a1State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_errorMessage,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|J0", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QIODevice, &a0, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setContents);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->setContents(a0, a1);
            sipReleaseType(a1, sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setContents);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->setContents(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setContents, doc_QDesignerFormWindowInterface_setContents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_features, "features(self) -> QDesignerFormWindowInterface.Feature");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_features(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_features(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QDesignerFormWindowInterface::Feature*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_features);
                return SIP_NULLPTR;
            }

            sipRes = new ::QDesignerFormWindowInterface::Feature(sipCpp->features());

            return sipConvertFromNewType(sipRes, sipType_QDesignerFormWindowInterface_Feature, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_features, doc_QDesignerFormWindowInterface_features);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_hasFeature, "hasFeature(self, f: Union[QDesignerFormWindowInterface.Feature, QDesignerFormWindowInterface.FeatureFlag]) -> bool");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_hasFeature(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_hasFeature(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowInterface::Feature* a0;
        int a0State = 0;
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QDesignerFormWindowInterface_Feature, &a0, &a0State))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_hasFeature);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->hasFeature(*a0);
            sipReleaseType(a0, sipType_QDesignerFormWindowInterface_Feature, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_hasFeature, doc_QDesignerFormWindowInterface_hasFeature);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_author, "author(self) -> str");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_author(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_author(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_author);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->author());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_author, doc_QDesignerFormWindowInterface_author);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setAuthor, "setAuthor(self, author: Optional[str])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setAuthor(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setAuthor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QString, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setAuthor);
                return SIP_NULLPTR;
            }

            sipCpp->setAuthor(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setAuthor, doc_QDesignerFormWindowInterface_setAuthor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_comment, "comment(self) -> str");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_comment(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_comment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_comment);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->comment());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_comment, doc_QDesignerFormWindowInterface_comment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setComment, "setComment(self, comment: Optional[str])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setComment(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setComment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QString, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setComment);
                return SIP_NULLPTR;
            }

            sipCpp->setComment(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setComment, doc_QDesignerFormWindowInterface_setComment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_layoutDefault, "layoutDefault(self) -> (Optional[int], Optional[int])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_layoutDefault(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_layoutDefault(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        int a1;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_layoutDefault);
                return SIP_NULLPTR;
            }

            sipCpp->layoutDefault(&a0, &a1);

            return sipBuildResult(0, "(ii)", a0, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_layoutDefault, doc_QDesignerFormWindowInterface_layoutDefault);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setLayoutDefault, "setLayoutDefault(self, margin: int, spacing: int)");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setLayoutDefault(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setLayoutDefault(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        int a1;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, &a0, &a1))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setLayoutDefault);
                return SIP_NULLPTR;
            }

            sipCpp->setLayoutDefault(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setLayoutDefault, doc_QDesignerFormWindowInterface_setLayoutDefault);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_layoutFunction, "layoutFunction(self) -> (Optional[str], Optional[str])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_layoutFunction(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_layoutFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QString* a0;
        ::QString* a1;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            a0 = new ::QString();
            a1 = new ::QString();

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_layoutFunction);
                return SIP_NULLPTR;
            }

            sipCpp->layoutFunction(a0, a1);

            return sipBuildResult(0, "(NN)", a0, sipType_QString, SIP_NULLPTR, a1, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_layoutFunction, doc_QDesignerFormWindowInterface_layoutFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setLayoutFunction, "setLayoutFunction(self, margin: Optional[str], spacing: Optional[str])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setLayoutFunction(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setLayoutFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setLayoutFunction);
                return SIP_NULLPTR;
            }

            sipCpp->setLayoutFunction(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setLayoutFunction, doc_QDesignerFormWindowInterface_setLayoutFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_pixmapFunction, "pixmapFunction(self) -> str");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_pixmapFunction(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_pixmapFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_pixmapFunction);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->pixmapFunction());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_pixmapFunction, doc_QDesignerFormWindowInterface_pixmapFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setPixmapFunction, "setPixmapFunction(self, pixmapFunction: Optional[str])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setPixmapFunction(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setPixmapFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QString, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setPixmapFunction);
                return SIP_NULLPTR;
            }

            sipCpp->setPixmapFunction(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setPixmapFunction, doc_QDesignerFormWindowInterface_setPixmapFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_exportMacro, "exportMacro(self) -> str");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_exportMacro(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_exportMacro(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_exportMacro);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->exportMacro());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_exportMacro, doc_QDesignerFormWindowInterface_exportMacro);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setExportMacro, "setExportMacro(self, exportMacro: Optional[str])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setExportMacro(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setExportMacro(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QString, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setExportMacro);
                return SIP_NULLPTR;
            }

            sipCpp->setExportMacro(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setExportMacro, doc_QDesignerFormWindowInterface_setExportMacro);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_includeHints, "includeHints(self) -> list[str]");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_includeHints(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_includeHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QStringList*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_includeHints);
                return SIP_NULLPTR;
            }

            sipRes = new ::QStringList(sipCpp->includeHints());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_includeHints, doc_QDesignerFormWindowInterface_includeHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setIncludeHints, "setIncludeHints(self, includeHints: Iterable[Optional[str]])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setIncludeHints(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setIncludeHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setIncludeHints);
                return SIP_NULLPTR;
            }

            sipCpp->setIncludeHints(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setIncludeHints, doc_QDesignerFormWindowInterface_setIncludeHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_core, "core(self) -> Optional[QDesignerFormEditorInterface]");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_core(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_core(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QDesignerFormEditorInterface*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QDesignerFormWindowInterface::core() : sipCpp->core());

            return sipConvertFromType(sipRes, sipType_QDesignerFormEditorInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_core, doc_QDesignerFormWindowInterface_core);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_cursor, "cursor(self) -> Optional[QDesignerFormWindowCursorInterface]");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_cursor(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_cursor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QDesignerFormWindowCursorInterface*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_cursor);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->cursor();

            return sipConvertFromType(sipRes, sipType_QDesignerFormWindowCursorInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_cursor, doc_QDesignerFormWindowInterface_cursor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_grid, "grid(self) -> QPoint");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_grid(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_grid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QPoint*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_grid);
                return SIP_NULLPTR;
            }

            sipRes = new ::QPoint(sipCpp->grid());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_grid, doc_QDesignerFormWindowInterface_grid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_mainContainer, "mainContainer(self) -> Optional[QWidget]");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_mainContainer(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_mainContainer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QWidget*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_mainContainer);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->mainContainer();

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_mainContainer, doc_QDesignerFormWindowInterface_mainContainer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setMainContainer, "setMainContainer(self, mainContainer: Optional[QWidget])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setMainContainer(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setMainContainer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QWidget* a0;
        PyObject *a0Keep;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, &a0Keep, sipType_QWidget, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setMainContainer);
                return SIP_NULLPTR;
            }

            sipCpp->setMainContainer(a0);

            sipKeepReference(sipSelf, -6, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setMainContainer, doc_QDesignerFormWindowInterface_setMainContainer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_isManaged, "isManaged(self, widget: Optional[QWidget]) -> bool");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_isManaged(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_isManaged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QWidget* a0;
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QWidget, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_isManaged);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isManaged(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_isManaged, doc_QDesignerFormWindowInterface_isManaged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_isDirty, "isDirty(self) -> bool");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_isDirty(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_isDirty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_isDirty);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isDirty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_isDirty, doc_QDesignerFormWindowInterface_isDirty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_findFormWindow, "findFormWindow(w: Optional[QWidget]) -> Optional[QDesignerFormWindowInterface]\n"
"findFormWindow(obj: Optional[QObject]) -> Optional[QDesignerFormWindowInterface]");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_findFormWindow(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_findFormWindow(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8", sipType_QWidget, &a0))
        {
            ::QDesignerFormWindowInterface*sipRes;

            sipRes = ::QDesignerFormWindowInterface::findFormWindow(a0);

            return sipConvertFromType(sipRes, sipType_QDesignerFormWindowInterface, SIP_NULLPTR);
        }
    }

    {
        ::QObject* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8", sipType_QObject, &a0))
        {
            ::QDesignerFormWindowInterface*sipRes;

            sipRes = ::QDesignerFormWindowInterface::findFormWindow(a0);

            return sipConvertFromType(sipRes, sipType_QDesignerFormWindowInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_findFormWindow, doc_QDesignerFormWindowInterface_findFormWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_emitSelectionChanged, "emitSelectionChanged(self)");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_emitSelectionChanged(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_emitSelectionChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_emitSelectionChanged);
                return SIP_NULLPTR;
            }

            sipCpp->emitSelectionChanged();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_emitSelectionChanged, doc_QDesignerFormWindowInterface_emitSelectionChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_resourceFiles, "resourceFiles(self) -> list[str]");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_resourceFiles(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_resourceFiles(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QStringList*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_resourceFiles);
                return SIP_NULLPTR;
            }

            sipRes = new ::QStringList(sipCpp->resourceFiles());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_resourceFiles, doc_QDesignerFormWindowInterface_resourceFiles);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_addResourceFile, "addResourceFile(self, path: Optional[str])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_addResourceFile(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_addResourceFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QString, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_addResourceFile);
                return SIP_NULLPTR;
            }

            sipCpp->addResourceFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_addResourceFile, doc_QDesignerFormWindowInterface_addResourceFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_removeResourceFile, "removeResourceFile(self, path: Optional[str])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_removeResourceFile(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_removeResourceFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QString, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_removeResourceFile);
                return SIP_NULLPTR;
            }

            sipCpp->removeResourceFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_removeResourceFile, doc_QDesignerFormWindowInterface_removeResourceFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_manageWidget, "manageWidget(self, widget: Optional[QWidget])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_manageWidget(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_manageWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QWidget* a0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QWidget, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_manageWidget);
                return SIP_NULLPTR;
            }

            sipCpp->manageWidget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_manageWidget, doc_QDesignerFormWindowInterface_manageWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_unmanageWidget, "unmanageWidget(self, widget: Optional[QWidget])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_unmanageWidget(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_unmanageWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QWidget* a0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QWidget, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_unmanageWidget);
                return SIP_NULLPTR;
            }

            sipCpp->unmanageWidget(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_unmanageWidget, doc_QDesignerFormWindowInterface_unmanageWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setFeatures, "setFeatures(self, f: Union[QDesignerFormWindowInterface.Feature, QDesignerFormWindowInterface.FeatureFlag])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setFeatures(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setFeatures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QDesignerFormWindowInterface::Feature* a0;
        int a0State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QDesignerFormWindowInterface_Feature, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setFeatures);
                return SIP_NULLPTR;
            }

            sipCpp->setFeatures(*a0);
            sipReleaseType(a0, sipType_QDesignerFormWindowInterface_Feature, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setFeatures, doc_QDesignerFormWindowInterface_setFeatures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setDirty, "setDirty(self, dirty: bool)");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setDirty(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setDirty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        bool a0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setDirty);
                return SIP_NULLPTR;
            }

            sipCpp->setDirty(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setDirty, doc_QDesignerFormWindowInterface_setDirty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_clearSelection, "clearSelection(self, update: bool = True)");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_clearSelection(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_clearSelection(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        bool a0 = 1;
        ::QDesignerFormWindowInterface *sipCpp;

        static const char *sipKwdList[] = {
            sipName_update,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_clearSelection);
                return SIP_NULLPTR;
            }

            sipCpp->clearSelection(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_clearSelection, doc_QDesignerFormWindowInterface_clearSelection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_selectWidget, "selectWidget(self, widget: Optional[QWidget], select: bool = True)");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_selectWidget(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_selectWidget(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QWidget* a0;
        bool a1 = 1;
        ::QDesignerFormWindowInterface *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_select,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|b", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QWidget, &a0, &a1))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_selectWidget);
                return SIP_NULLPTR;
            }

            sipCpp->selectWidget(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_selectWidget, doc_QDesignerFormWindowInterface_selectWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setGrid, "setGrid(self, grid: QPoint)");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setGrid(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setGrid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QPoint* a0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QPoint, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setGrid);
                return SIP_NULLPTR;
            }

            sipCpp->setGrid(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setGrid, doc_QDesignerFormWindowInterface_setGrid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_setFileName, "setFileName(self, fileName: Optional[str])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_setFileName(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_setFileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QString, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_setFileName);
                return SIP_NULLPTR;
            }

            sipCpp->setFileName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_setFileName, doc_QDesignerFormWindowInterface_setFileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_checkContents, "checkContents(self) -> list[str]");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_checkContents(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_checkContents(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QStringList*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_checkContents);
                return SIP_NULLPTR;
            }

            sipRes = new ::QStringList(sipCpp->checkContents());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_checkContents, doc_QDesignerFormWindowInterface_checkContents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_activeResourceFilePaths, "activeResourceFilePaths(self) -> list[str]");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_activeResourceFilePaths(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_activeResourceFilePaths(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->activeResourceFilePaths());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_activeResourceFilePaths, doc_QDesignerFormWindowInterface_activeResourceFilePaths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_formContainer, "formContainer(self) -> Optional[QWidget]");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_formContainer(PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_formContainer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerFormWindowInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp))
        {
            ::QWidget*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerFormWindowInterface, sipName_formContainer);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->formContainer();

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_formContainer, doc_QDesignerFormWindowInterface_formContainer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerFormWindowInterface_activateResourceFilePaths, "activateResourceFilePaths(self, paths: Iterable[Optional[str]]) -> (Optional[int], Optional[str])");

extern "C" {static PyObject *meth_QDesignerFormWindowInterface_activateResourceFilePaths(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QDesignerFormWindowInterface_activateResourceFilePaths(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        int a1;
        ::QString* a2;
        ::QDesignerFormWindowInterface *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QDesignerFormWindowInterface, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            a2 = new ::QString();

            sipCpp->activateResourceFilePaths(*a0, &a1, a2);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            return sipBuildResult(0, "(iN)", a1, a2, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerFormWindowInterface, sipName_activateResourceFilePaths, doc_QDesignerFormWindowInterface_activateResourceFilePaths);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QDesignerFormWindowInterface(void *, const sipTypeDef *);}
static void *cast_QDesignerFormWindowInterface(void *sipCppV, const sipTypeDef *targetType)
{
    ::QDesignerFormWindowInterface *sipCpp = reinterpret_cast< ::QDesignerFormWindowInterface *>(sipCppV);

    if (targetType == sipType_QDesignerFormWindowInterface)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast< ::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDesignerFormWindowInterface(void *, int);}
static void release_QDesignerFormWindowInterface(void *sipCppV, int)
{
    ::QDesignerFormWindowInterface *sipCpp = reinterpret_cast< ::QDesignerFormWindowInterface *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QDesignerFormWindowInterface(sipSimpleWrapper *);}
static void dealloc_QDesignerFormWindowInterface(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDesignerFormWindowInterface(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QDesignerFormWindowInterface[] = {{3, 2, 1}};


static PyMethodDef methods_QDesignerFormWindowInterface[] = {
    {sipName_absoluteDir, meth_QDesignerFormWindowInterface_absoluteDir, METH_VARARGS, doc_QDesignerFormWindowInterface_absoluteDir},
    {sipName_activateResourceFilePaths, SIP_MLMETH_CAST(meth_QDesignerFormWindowInterface_activateResourceFilePaths), METH_VARARGS|METH_KEYWORDS, doc_QDesignerFormWindowInterface_activateResourceFilePaths},
    {sipName_activeResourceFilePaths, meth_QDesignerFormWindowInterface_activeResourceFilePaths, METH_VARARGS, doc_QDesignerFormWindowInterface_activeResourceFilePaths},
    {sipName_addResourceFile, meth_QDesignerFormWindowInterface_addResourceFile, METH_VARARGS, doc_QDesignerFormWindowInterface_addResourceFile},
    {sipName_author, meth_QDesignerFormWindowInterface_author, METH_VARARGS, doc_QDesignerFormWindowInterface_author},
    {sipName_checkContents, meth_QDesignerFormWindowInterface_checkContents, METH_VARARGS, doc_QDesignerFormWindowInterface_checkContents},
    {sipName_clearSelection, SIP_MLMETH_CAST(meth_QDesignerFormWindowInterface_clearSelection), METH_VARARGS|METH_KEYWORDS, doc_QDesignerFormWindowInterface_clearSelection},
    {sipName_comment, meth_QDesignerFormWindowInterface_comment, METH_VARARGS, doc_QDesignerFormWindowInterface_comment},
    {sipName_contents, meth_QDesignerFormWindowInterface_contents, METH_VARARGS, doc_QDesignerFormWindowInterface_contents},
    {sipName_core, meth_QDesignerFormWindowInterface_core, METH_VARARGS, doc_QDesignerFormWindowInterface_core},
    {sipName_cursor, meth_QDesignerFormWindowInterface_cursor, METH_VARARGS, doc_QDesignerFormWindowInterface_cursor},
    {sipName_emitSelectionChanged, meth_QDesignerFormWindowInterface_emitSelectionChanged, METH_VARARGS, doc_QDesignerFormWindowInterface_emitSelectionChanged},
    {sipName_exportMacro, meth_QDesignerFormWindowInterface_exportMacro, METH_VARARGS, doc_QDesignerFormWindowInterface_exportMacro},
    {sipName_features, meth_QDesignerFormWindowInterface_features, METH_VARARGS, doc_QDesignerFormWindowInterface_features},
    {sipName_fileName, meth_QDesignerFormWindowInterface_fileName, METH_VARARGS, doc_QDesignerFormWindowInterface_fileName},
    {sipName_findFormWindow, meth_QDesignerFormWindowInterface_findFormWindow, METH_VARARGS, doc_QDesignerFormWindowInterface_findFormWindow},
    {sipName_formContainer, meth_QDesignerFormWindowInterface_formContainer, METH_VARARGS, doc_QDesignerFormWindowInterface_formContainer},
    {sipName_grid, meth_QDesignerFormWindowInterface_grid, METH_VARARGS, doc_QDesignerFormWindowInterface_grid},
    {sipName_hasFeature, meth_QDesignerFormWindowInterface_hasFeature, METH_VARARGS, doc_QDesignerFormWindowInterface_hasFeature},
    {sipName_includeHints, meth_QDesignerFormWindowInterface_includeHints, METH_VARARGS, doc_QDesignerFormWindowInterface_includeHints},
    {sipName_isDirty, meth_QDesignerFormWindowInterface_isDirty, METH_VARARGS, doc_QDesignerFormWindowInterface_isDirty},
    {sipName_isManaged, meth_QDesignerFormWindowInterface_isManaged, METH_VARARGS, doc_QDesignerFormWindowInterface_isManaged},
    {sipName_layoutDefault, meth_QDesignerFormWindowInterface_layoutDefault, METH_VARARGS, doc_QDesignerFormWindowInterface_layoutDefault},
    {sipName_layoutFunction, meth_QDesignerFormWindowInterface_layoutFunction, METH_VARARGS, doc_QDesignerFormWindowInterface_layoutFunction},
    {sipName_mainContainer, meth_QDesignerFormWindowInterface_mainContainer, METH_VARARGS, doc_QDesignerFormWindowInterface_mainContainer},
    {sipName_manageWidget, meth_QDesignerFormWindowInterface_manageWidget, METH_VARARGS, doc_QDesignerFormWindowInterface_manageWidget},
    {sipName_pixmapFunction, meth_QDesignerFormWindowInterface_pixmapFunction, METH_VARARGS, doc_QDesignerFormWindowInterface_pixmapFunction},
    {sipName_removeResourceFile, meth_QDesignerFormWindowInterface_removeResourceFile, METH_VARARGS, doc_QDesignerFormWindowInterface_removeResourceFile},
    {sipName_resourceFiles, meth_QDesignerFormWindowInterface_resourceFiles, METH_VARARGS, doc_QDesignerFormWindowInterface_resourceFiles},
    {sipName_selectWidget, SIP_MLMETH_CAST(meth_QDesignerFormWindowInterface_selectWidget), METH_VARARGS|METH_KEYWORDS, doc_QDesignerFormWindowInterface_selectWidget},
    {sipName_setAuthor, meth_QDesignerFormWindowInterface_setAuthor, METH_VARARGS, doc_QDesignerFormWindowInterface_setAuthor},
    {sipName_setComment, meth_QDesignerFormWindowInterface_setComment, METH_VARARGS, doc_QDesignerFormWindowInterface_setComment},
    {sipName_setContents, SIP_MLMETH_CAST(meth_QDesignerFormWindowInterface_setContents), METH_VARARGS|METH_KEYWORDS, doc_QDesignerFormWindowInterface_setContents},
    {sipName_setDirty, meth_QDesignerFormWindowInterface_setDirty, METH_VARARGS, doc_QDesignerFormWindowInterface_setDirty},
    {sipName_setExportMacro, meth_QDesignerFormWindowInterface_setExportMacro, METH_VARARGS, doc_QDesignerFormWindowInterface_setExportMacro},
    {sipName_setFeatures, meth_QDesignerFormWindowInterface_setFeatures, METH_VARARGS, doc_QDesignerFormWindowInterface_setFeatures},
    {sipName_setFileName, meth_QDesignerFormWindowInterface_setFileName, METH_VARARGS, doc_QDesignerFormWindowInterface_setFileName},
    {sipName_setGrid, meth_QDesignerFormWindowInterface_setGrid, METH_VARARGS, doc_QDesignerFormWindowInterface_setGrid},
    {sipName_setIncludeHints, meth_QDesignerFormWindowInterface_setIncludeHints, METH_VARARGS, doc_QDesignerFormWindowInterface_setIncludeHints},
    {sipName_setLayoutDefault, meth_QDesignerFormWindowInterface_setLayoutDefault, METH_VARARGS, doc_QDesignerFormWindowInterface_setLayoutDefault},
    {sipName_setLayoutFunction, meth_QDesignerFormWindowInterface_setLayoutFunction, METH_VARARGS, doc_QDesignerFormWindowInterface_setLayoutFunction},
    {sipName_setMainContainer, meth_QDesignerFormWindowInterface_setMainContainer, METH_VARARGS, doc_QDesignerFormWindowInterface_setMainContainer},
    {sipName_setPixmapFunction, meth_QDesignerFormWindowInterface_setPixmapFunction, METH_VARARGS, doc_QDesignerFormWindowInterface_setPixmapFunction},
    {sipName_unmanageWidget, meth_QDesignerFormWindowInterface_unmanageWidget, METH_VARARGS, doc_QDesignerFormWindowInterface_unmanageWidget}
};

static sipEnumMemberDef enummembers_QDesignerFormWindowInterface[] = {
    {sipName_DefaultFeature, static_cast<int>(::QDesignerFormWindowInterface::DefaultFeature), 13},
    {sipName_EditFeature, static_cast<int>(::QDesignerFormWindowInterface::EditFeature), 13},
    {sipName_GridFeature, static_cast<int>(::QDesignerFormWindowInterface::GridFeature), 13},
    {sipName_TabOrderFeature, static_cast<int>(::QDesignerFormWindowInterface::TabOrderFeature), 13},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QDesignerFormWindowInterface[] = {
    {"objectRemoved(QObject*)", "\1objectRemoved(self, o: Optional[QObject])", SIP_NULLPTR, SIP_NULLPTR},
    {"widgetRemoved(QWidget*)", "\1widgetRemoved(self, w: Optional[QWidget])", SIP_NULLPTR, SIP_NULLPTR},
    {"changed()", "\1changed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"activated(QWidget*)", "\1activated(self, widget: Optional[QWidget])", SIP_NULLPTR, SIP_NULLPTR},
    {"aboutToUnmanageWidget(QWidget*)", "\1aboutToUnmanageWidget(self, widget: Optional[QWidget])", SIP_NULLPTR, SIP_NULLPTR},
    {"widgetUnmanaged(QWidget*)", "\1widgetUnmanaged(self, widget: Optional[QWidget])", SIP_NULLPTR, SIP_NULLPTR},
    {"widgetManaged(QWidget*)", "\1widgetManaged(self, widget: Optional[QWidget])", SIP_NULLPTR, SIP_NULLPTR},
    {"resourceFilesChanged()", "\1resourceFilesChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"geometryChanged()", "\1geometryChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"selectionChanged()", "\1selectionChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"featureChanged(Feature)|(QDesignerFormWindowInterface::Feature)", "\1featureChanged(self, f: Union[QDesignerFormWindowInterface.Feature, QDesignerFormWindowInterface.FeatureFlag])", SIP_NULLPTR, SIP_NULLPTR},
    {"fileNameChanged(QString)", "\1fileNameChanged(self, fileName: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"mainContainerChanged(QWidget*)", "\1mainContainerChanged(self, mainContainer: Optional[QWidget])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QDesignerFormWindowInterface = {
    &::QDesignerFormWindowInterface::staticMetaObject,
    0,
    signals_QDesignerFormWindowInterface,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormWindowInterface = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDesignerFormWindowInterface,
        SIP_NULLPTR,
        &plugin_QDesignerFormWindowInterface,
    },
    {
        sipNameNr_QDesignerFormWindowInterface,
        {0, 0, 1},
        44, methods_QDesignerFormWindowInterface,
        4, enummembers_QDesignerFormWindowInterface,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QDesignerFormWindowInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDesignerFormWindowInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QDesignerFormWindowInterface,
    cast_QDesignerFormWindowInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
